@@ -19,7 +19,7 @@ class Request:
             return self._requester_base.get(url, headers=headers, params=query_params)
 
     @http_exception
-    def post(self, url: str, files: Optional[Dict], headers: Dict = {}, data: Dict = {}):
+    def post(self, url: str, files: Optional[Dict] = {}, headers: Dict = {}, data: Dict = {}):
         if self.validation == 'False':
             return self._requester_base.post(url, files=files, headers=headers, data=data, verify=False)
         else:
